from fenics import *
mesh = UnitIntervalMesh(10)
V = FunctionSpace(mesh, 'CG', 1)
v = TestFunction(V)
def q(u): return (1 + u)**2 
def lb(x): return near(x[0], 0)
def rb(x): return near(x[0], 1)
lc = DirichletBC(V, 0, lb)
rc = DirichletBC(V, 1, rb)
bc = [lc, rc]
u_n = project(Constant(0), V)   # u_n is of type 'Function'
u = Function(V)   # not TrialFunction
eps = 1.0E-6
import numpy
for _ in range(25): 
    F = q(u_n) * u.dx(0) * v.dx(0) * dx
    solve(F == 0, u, bc) 
    diff = u.vector().array() - u_n.vector().array()
    d = numpy.linalg.norm(diff, ord=numpy.Inf)
    if d < eps: break
    u_n.assign(u) 
plot(u, interactive = True)
