from fenics import *
mesh = UnitSquareMesh(32,32)
ue = VectorElement("CG", triangle, 2)
pe = FiniteElement("CG", triangle, 1)
W = FunctionSpace(mesh, ue*pe)
(u,p) = TrialFunctions(W)
(v,q) = TestFunctions(W)
u_ex = Expression(('cos(pi*x[1])', 'sin(pi*x[0])'), degree=1) 
bc = DirichletBC(W.sub(0), u_ex, 'on_boundary')
f = Expression(('pi*pi * (cos(pi*x[1]) - sin(pi*x[0])*cos(pi*x[1]))',  \
                'pi*pi * (sin(pi*x[0]) - sin(pi*x[1])*cos(pi*x[0]))'), \
                 degree=1)
a = inner(grad(u), grad(v))*dx - p*div(v)*dx + q*div(u)*dx
L = inner(f,v)*dx
w = Function(W)
solve(a == L, w, bc)
(u, p) = w.split(True)
plot(u, title="Velocity", interactive=True)
uex = interpolate(u_ex, W.sub(0).collapse())
plot(uex, title="Exact Velocity", interactive=True)
normalize(p.vector())
plot(p, title="Pressure", interactive=True)
p_ex = Expression('pi * cos(pi*x[0]) * cos(pi*x[1])', degree=1)
pex = interpolate(p_ex, W.sub(1).collapse())
plot(pex, title="Exact Pressure", interactive=True)


#execfile('/home/parallels/Desktop/stokes.py' )


